
# Changelog
All notable changes to tailbone-corepos will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [0.1.1] - 2020-02-27
### Changed
- Add support for multiple DB engines, and HouseCoupon views.
- Show proper flags breakdown for products.
- Highlight inactive product flags as 'warning' in grid.
- Add master view for Parameter model.
- Allow CRUD actions by default, for CORE master views.
- Hide some problematic fields for create/edit CORE customer.
- Cleanup various attribute names, per changes in pyCOREPOS.

## [0.1.0] - 2019-07-09
### Changed
- Initial release.
